@@ -9,5 +9,9 @@ CONSUMER_MPA_CLIENT_ID = "test-consumer-mpa-client"
 PRODUCER_MPA_CLIENT_ID = "test-producer-mpa-client"
 PROCESSOR_MPA_CLIENT_ID = "test-processor-mpa-client"
 INBOUND_TOPIC = "test-mpa-inbound-topic-name"
+DURABLE_INBOUND_TOPIC = "test-mpa-durable-inbound-topic-name"
+DURABLE_INBOUND_PROC_TOPIC = "test-mpa-durable-inbound-proc-topic-name"
 OUTBOUND_TOPIC = "test-mpa-outbound-topic-name"
+DURABLE_OUTBOUND_TOPIC = "test-mpa-durable-outbound-topic-name"
+DURABLE_OUTBOUND_PROC_TOPIC = "test-mpa-durable-outbound-proc-topic-name"
 TEST_PAYLOAD = b"test payload..."
